@@ -1,3 +1,4 @@
+import regeneratorRuntime from "regenerator-runtime";
 function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
     try {
         var info = gen[key](arg);
@@ -27,7 +28,6 @@ function _asyncToGenerator(fn) {
         });
     };
 }
-var regeneratorRuntime = require("regenerator-runtime");
 var obj = {
     find: function(param) {
         var platform = param.platform;
